@@ -4,7 +4,7 @@ import (
 	"context"
 	"reflect"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	inference "github.com/scaleway/scaleway-sdk-go/api/inference/v1beta1"
 )
 
