@@ -9,7 +9,7 @@ import (
 
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/core"
-	"github.com/scaleway/scaleway-cli/v2/internal/human"
+	"github.com/scaleway/scaleway-cli/v2/core/human"
 	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
@@ -188,7 +188,14 @@ func imageListBuilder(c *core.Command) *core.Command {
 		req.Public = scw.BoolPtr(false)
 		client := core.ExtractClient(ctx)
 		api := instance.NewAPI(client)
-		listImagesResponse, err := api.ListImages(req, scw.WithAllPages())
+
+		opts := []scw.RequestOption{scw.WithAllPages()}
+		if req.Zone == scw.Zone(core.AllLocalities) {
+			opts = append(opts, scw.WithZones(api.Zones()...))
+			req.Zone = ""
+		}
+
+		listImagesResponse, err := api.ListImages(req, opts...)
 		if err != nil {
 			return nil, err
 		}
@@ -289,9 +296,11 @@ func imageDeleteBuilder(c *core.Command) *core.Command {
 			}
 			for _, snapshot := range snapshots {
 				if snapshot.Type == instance.VolumeVolumeTypeSbsSnapshot {
+					terminalStatus := block.SnapshotStatusAvailable
 					_, err := blockAPI.WaitForSnapshot(&block.WaitForSnapshotRequest{
-						SnapshotID: snapshot.ID,
-						Zone:       args.Zone,
+						SnapshotID:     snapshot.ID,
+						Zone:           args.Zone,
+						TerminalStatus: &terminalStatus,
 					})
 					if err != nil {
 						return nil, err
