@@ -6,7 +6,9 @@ import (
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
+	block "github.com/scaleway/scaleway-cli/v2/internal/namespaces/block/v1alpha1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
+	"github.com/scaleway/scaleway-cli/v2/internal/testhelpers"
 	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/stretchr/testify/require"
@@ -19,7 +21,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("without IP", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy -w")),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy ip=new -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }}`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -27,7 +29,8 @@ func Test_ServerTerminate(t *testing.T) {
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				server := testhelpers.MapValue[*instanceSDK.Server](t, ctx.Meta, "Server")
+				assert.NotNil(t, server.PublicIP)
 				_, err := api.GetIP(&instanceSDK.GetIPRequest{
 					IP: server.PublicIP.ID,
 				})
@@ -40,7 +43,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("with IP", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy -w")),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy ip=new -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -48,19 +51,23 @@ func Test_ServerTerminate(t *testing.T) {
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				server := testhelpers.MapValue[*instanceSDK.Server](t, ctx.Meta, "Server")
+				assert.NotNil(t, server.PublicIP)
+
 				_, err := api.GetIP(&instanceSDK.GetIPRequest{
 					IP: server.PublicIP.ID,
 				})
-				require.IsType(t, &scw.ResponseError{}, err)
-				assert.Equal(t, 403, err.(*scw.ResponseError).StatusCode)
+				require.IsType(t, &scw.PermissionsDeniedError{}, err)
 			},
 		),
 		DisableParallel: true,
 	}))
 
 	t.Run("without block", core.Test(&core.TestConfig{
-		Commands:   instance.GetCommands(),
+		Commands: core.NewCommandsMerge(
+			instance.GetCommands(),
+			block.GetCommands(),
+		),
 		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy additional-volumes.0=block:10G -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true with-block=false`,
 		Check: core.TestCheckCombine(
@@ -68,8 +75,8 @@ func Test_ServerTerminate(t *testing.T) {
 			core.TestCheckExitCode(0),
 		),
 		AfterFunc: core.AfterFuncCombine(
-			core.ExecAfterCmd(`scw instance volume wait {{ (index .Server.Volumes "1").ID }}`),
-			core.ExecAfterCmd(`scw instance volume delete {{ (index .Server.Volumes "1").ID }}`),
+			core.ExecAfterCmd(`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`),
+			core.ExecAfterCmd(`scw block volume delete {{ (index .Server.Volumes "1").ID }}`),
 		),
 		DisableParallel: true,
 	}))
@@ -84,9 +91,11 @@ func Test_ServerTerminate(t *testing.T) {
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				server := testhelpers.MapValue[*instanceSDK.Server](t, ctx.Meta, "Server")
+				volume := testhelpers.MapTValue(t, server.Volumes, "0")
+
 				_, err := api.GetVolume(&instanceSDK.GetVolumeRequest{
-					VolumeID: server.Volumes["0"].ID,
+					VolumeID: volume.ID,
 					Zone:     server.Zone,
 				})
 				require.IsType(t, &scw.ResourceNotFoundError{}, err)
@@ -117,7 +126,7 @@ func Test_ServerBackup(t *testing.T) {
 
 	t.Run("With SBS volumes", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("root-volume=sbs:20G stopped=true image=ubuntu-jammy")),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("root-volume=sbs:20G additional-volumes.0=sbs:10G additional-volumes.1=sbs:15G stopped=true image=ubuntu-jammy")),
 		Cmd:        `scw instance server backup {{ .Server.ID }} name=backup`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -139,7 +148,7 @@ func Test_ServerAction(t *testing.T) {
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				storedServer := ctx.Meta["Server"].(*instanceSDK.Server)
+				storedServer := testhelpers.MapValue[*instanceSDK.Server](t, ctx.Meta, "Server")
 				api := instanceSDK.NewAPI(ctx.Client)
 				resp, err := api.GetServer(&instanceSDK.GetServerRequest{
 					Zone:     storedServer.Zone,
