@@ -118,22 +118,12 @@ func (sb *ServerBuilder) isWindows() bool {
 	return commercialTypeIsWindowsServer(sb.createReq.CommercialType)
 }
 
-func (sb *ServerBuilder) rootVolumeTemplate() *instance.VolumeServerTemplate {
-	rootVolume, exists := sb.createReq.Volumes["0"]
-	if !exists {
-		return nil
-	}
-
-	return rootVolume
-}
-
 func (sb *ServerBuilder) rootVolumeIsSBS() bool {
-	rootVolume := sb.rootVolumeTemplate()
-	if rootVolume == nil {
+	if sb.rootVolume == nil {
 		return false
 	}
 
-	return rootVolume.VolumeType == instance.VolumeVolumeTypeSbsVolume
+	return sb.rootVolume.VolumeType == instance.VolumeVolumeTypeSbsVolume
 }
 
 func (sb *ServerBuilder) marketplaceImageType() marketplace.LocalImageType {
@@ -174,7 +164,7 @@ func (sb *ServerBuilder) AddImage(image string) (*ServerBuilder, error) {
 		ImageID: *(sb.createReq.Image),
 	})
 	if err != nil {
-		logger.Warningf("cannot get image %s: %s", sb.createReq.Image, err)
+		logger.Warningf("cannot get image %s: %s", *sb.createReq.Image, err)
 	} else {
 		sb.serverImage = getImageResponse.Image
 	}
@@ -237,14 +227,22 @@ func (sb *ServerBuilder) AddIP(ip string) (*ServerBuilder, error) {
 	return sb, nil
 }
 
+func (sb *ServerBuilder) addIPID(ipID string) *ServerBuilder {
+	if sb.createReq.PublicIPs == nil {
+		sb.createReq.PublicIPs = new([]string)
+	}
+
+	*sb.createReq.PublicIPs = append(*sb.createReq.PublicIPs, ipID)
+
+	return sb
+}
+
 // AddVolumes build volume templates from arguments.
 //
 // More format details in buildVolumeTemplate function.
 //
 // Also add default volumes to server, ex: scratch storage for GPU servers
 func (sb *ServerBuilder) AddVolumes(rootVolume string, additionalVolumes []string) (*ServerBuilder, error) {
-	var err error
-
 	if len(additionalVolumes) > 0 || rootVolume != "" {
 		if rootVolume != "" {
 			rootVolumeBuilder, err := NewVolumeBuilder(sb.createReq.Zone, rootVolume)
@@ -260,29 +258,6 @@ func (sb *ServerBuilder) AddVolumes(rootVolume string, additionalVolumes []strin
 			}
 			sb.volumes = append(sb.volumes, additionalVolumeBuilder)
 		}
-
-		volumes := make(map[string]*instance.VolumeServerTemplate, len(sb.volumes)+1)
-		if sb.rootVolume != nil {
-			volumes["0"], err = sb.rootVolume.BuildVolumeServerTemplate(sb.apiInstance, sb.apiBlock)
-			if err != nil {
-				return sb, fmt.Errorf("failed to build root volume: %w", err)
-			}
-		}
-		for i, volume := range sb.volumes {
-			volumeTemplate, err := volume.BuildVolumeServerTemplate(sb.apiInstance, sb.apiBlock)
-			if err != nil {
-				return sb, fmt.Errorf("failed to build volume template: %w", err)
-			}
-			index := strconv.Itoa(i + 1)
-			volumeTemplate.Name = scw.StringPtr(sb.createReq.Name + "-" + index)
-			volumes[index] = volumeTemplate
-		}
-		// Sanitize the volume map to respect API schemas
-		sb.createReq.Volumes = volumes
-	}
-
-	if sb.serverType != nil {
-		sb.createReq.Volumes = addDefaultVolumes(sb.serverType, sb.createReq.Volumes)
 	}
 
 	return sb, nil
@@ -299,7 +274,7 @@ func (sb *ServerBuilder) ValidateVolumes() error {
 				return err
 			}
 		} else {
-			logger.Warningf("skipping root volume validation")
+			logger.Warningf("skipping root volume validation\n")
 		}
 
 		// Validate total local volume sizes.
@@ -308,7 +283,7 @@ func (sb *ServerBuilder) ValidateVolumes() error {
 				return err
 			}
 		} else {
-			logger.Warningf("skip local volume size validation")
+			logger.Warningf("skip local volume size validation\n")
 		}
 
 		// Sanitize the volume map to respect API schemas
@@ -360,11 +335,148 @@ func (sb *ServerBuilder) Validate() error {
 		logger.Warningf("skipping image server-type compatibility validation")
 	}
 
-	return sb.ValidateVolumes()
+	return nil
 }
 
-func (sb *ServerBuilder) Build() (*instance.CreateServerRequest, []*instance.CreateIPRequest) {
-	return sb.createReq, sb.createIPReqs
+func (sb *ServerBuilder) BuildVolumes() error {
+	var err error
+
+	volumes := make(map[string]*instance.VolumeServerTemplate, len(sb.volumes)+1)
+	if sb.rootVolume != nil {
+		volumes["0"], err = sb.rootVolume.BuildVolumeServerTemplate(sb.apiInstance, sb.apiBlock)
+		if err != nil {
+			return fmt.Errorf("failed to build root volume: %w", err)
+		}
+	}
+
+	for i, volume := range sb.volumes {
+		volumeTemplate, err := volume.BuildVolumeServerTemplate(sb.apiInstance, sb.apiBlock)
+		if err != nil {
+			return fmt.Errorf("failed to build volume template: %w", err)
+		}
+		index := strconv.Itoa(i + 1)
+		volumeTemplate.Name = scw.StringPtr(sb.createReq.Name + "-" + index)
+		volumes[index] = volumeTemplate
+	}
+	// Sanitize the volume map to respect API schemas
+	sb.createReq.Volumes = volumes
+
+	if sb.serverType != nil {
+		sb.createReq.Volumes = addDefaultVolumes(sb.serverType, sb.createReq.Volumes)
+	}
+
+	return nil
+}
+
+func (sb *ServerBuilder) Build() (*instance.CreateServerRequest, error) {
+	err := sb.BuildVolumes()
+	if err != nil {
+		return nil, err
+	}
+
+	return sb.createReq, sb.ValidateVolumes()
+}
+
+type PreServerCreationSetupFunc func(ctx context.Context) error
+
+type PreServerCreationSetup struct {
+	setupFunctions []PreServerCreationSetupFunc
+	cleanFunctions []PreServerCreationSetupFunc
+}
+
+func (sb *ServerBuilder) BuildPreCreationSetup() *PreServerCreationSetup {
+	setup := &PreServerCreationSetup{}
+
+	for _, ipCreationRequest := range sb.createIPReqs {
+		setup.setupFunctions = append(setup.setupFunctions, func(ctx context.Context) error {
+			resp, err := sb.apiInstance.CreateIP(ipCreationRequest, scw.WithContext(ctx))
+			if err != nil {
+				return err
+			}
+
+			sb.addIPID(resp.IP.ID)
+
+			setup.cleanFunctions = append(setup.cleanFunctions, func(ctx context.Context) error {
+				return sb.apiInstance.DeleteIP(&instance.DeleteIPRequest{
+					IP:   resp.IP.ID,
+					Zone: resp.IP.Zone,
+				}, scw.WithContext(ctx))
+			})
+
+			return nil
+		})
+	}
+
+	sb.BuildPreCreationVolumesSetup(setup)
+
+	return setup
+}
+
+// BuildPreCreationVolumesSetup configure PreServerCreationSetup to create required SBS volumes.
+// Instance API does not support SBS volumes creation alongside the server, they must be created before then imported.
+func (sb *ServerBuilder) BuildPreCreationVolumesSetup(setup *PreServerCreationSetup) {
+	for _, volume := range sb.volumes {
+		if volume.VolumeType != instance.VolumeVolumeTypeSbsVolume || volume.VolumeID != nil || volume.Size == nil {
+			continue
+		}
+
+		projectID := "" // If let empty, ProjectID will be set by scaleway client to default Project ID.
+		if sb.createReq.Project != nil {
+			projectID = *sb.createReq.Project
+		}
+
+		setup.setupFunctions = append(setup.setupFunctions, func(ctx context.Context) error {
+			vol, err := sb.apiBlock.CreateVolume(&block.CreateVolumeRequest{
+				Zone:      volume.Zone,
+				Name:      core.GetRandomName("vol"),
+				PerfIops:  volume.IOPS,
+				ProjectID: projectID,
+				FromEmpty: &block.CreateVolumeRequestFromEmpty{
+					Size: *volume.Size,
+				},
+			}, scw.WithContext(ctx))
+			if err != nil {
+				return err
+			}
+
+			volume.VolumeID = &vol.ID
+
+			setup.cleanFunctions = append(setup.cleanFunctions, func(ctx context.Context) error {
+				return sb.apiBlock.DeleteVolume(&block.DeleteVolumeRequest{
+					Zone:     vol.Zone,
+					VolumeID: vol.ID,
+				}, scw.WithContext(ctx))
+			})
+
+			return nil
+		})
+	}
+}
+
+func (s *PreServerCreationSetup) Execute(ctx context.Context) error {
+	for _, setupFunc := range s.setupFunctions {
+		if err := setupFunc(ctx); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func (s *PreServerCreationSetup) Clean(ctx context.Context) error {
+	errs := []error(nil)
+
+	for _, cleanFunc := range s.cleanFunctions {
+		if err := cleanFunc(ctx); err != nil {
+			errs = append(errs, err)
+		}
+	}
+
+	if len(errs) > 0 {
+		return errors.Join(errs...)
+	}
+
+	return nil
 }
 
 type PostServerCreationSetupFunc func(ctx context.Context, server *instance.Server) error
@@ -434,12 +546,11 @@ func NewVolumeBuilder(zone scw.Zone, flagV string) (*VolumeBuilder, error) {
 		switch parts[0] {
 		case "l", "local":
 			vb.VolumeType = instance.VolumeVolumeTypeLSSD
-		case "b", "block":
-			vb.VolumeType = instance.VolumeVolumeTypeBSSD
+		case "sbs", "b", "block":
+			vb.VolumeType = instance.VolumeVolumeTypeSbsVolume
 		case "s", "scratch":
 			vb.VolumeType = instance.VolumeVolumeTypeScratch
-		case "sbs":
-			vb.VolumeType = instance.VolumeVolumeTypeSbsVolume
+
 		default:
 			return nil, fmt.Errorf("invalid volume type %s in %s volume", parts[0], flagV)
 		}
@@ -472,7 +583,7 @@ func NewVolumeBuilder(zone scw.Zone, flagV string) (*VolumeBuilder, error) {
 }
 
 // buildSnapshotVolume builds the requested volume template to create a new volume from a snapshot
-func (vb *VolumeBuilder) buildSnapshotVolume(api *instance.API) (*instance.VolumeServerTemplate, error) {
+func (vb *VolumeBuilder) buildSnapshotVolume(api *instance.API, blockAPI *block.API) (*instance.VolumeServerTemplate, error) {
 	if vb.SnapshotID == nil {
 		return nil, errors.New("tried to build a volume from snapshot with an empty ID")
 	}
@@ -480,23 +591,41 @@ func (vb *VolumeBuilder) buildSnapshotVolume(api *instance.API) (*instance.Volum
 		Zone:       vb.Zone,
 		SnapshotID: *vb.SnapshotID,
 	})
+	if err != nil && !core.IsNotFoundError(err) {
+		return nil, fmt.Errorf("invalid snapshot %s: %w", *vb.SnapshotID, err)
+	}
+
+	if res != nil {
+		snapshotType := res.Snapshot.VolumeType
+
+		if snapshotType != instance.VolumeVolumeTypeUnified && snapshotType != vb.VolumeType {
+			return nil, fmt.Errorf("snapshot of type %s not compatible with requested volume type %s", snapshotType, vb.VolumeType)
+		}
+
+		return &instance.VolumeServerTemplate{
+			Name:         &res.Snapshot.Name,
+			VolumeType:   vb.VolumeType,
+			BaseSnapshot: &res.Snapshot.ID,
+			Size:         &res.Snapshot.Size,
+		}, nil
+	}
+
+	blockRes, err := blockAPI.GetSnapshot(&block.GetSnapshotRequest{
+		Zone:       vb.Zone,
+		SnapshotID: *vb.SnapshotID,
+	})
 	if err != nil {
 		if core.IsNotFoundError(err) {
 			return nil, fmt.Errorf("snapshot %s does not exist", *vb.SnapshotID)
 		}
-	}
-
-	snapshotType := res.Snapshot.VolumeType
-
-	if snapshotType != instance.VolumeVolumeTypeUnified && snapshotType != vb.VolumeType {
-		return nil, fmt.Errorf("snapshot of type %s not compatible with requested volume type %s", snapshotType, vb.VolumeType)
+		return nil, err
 	}
 
 	return &instance.VolumeServerTemplate{
-		Name:         &res.Snapshot.Name,
+		Name:         &blockRes.Name,
 		VolumeType:   vb.VolumeType,
-		BaseSnapshot: &res.Snapshot.ID,
-		Size:         &res.Snapshot.Size,
+		BaseSnapshot: &blockRes.ID,
+		Size:         &blockRes.Size,
 	}, nil
 }
 
@@ -559,7 +688,7 @@ func (vb *VolumeBuilder) buildNewVolume() (*instance.VolumeServerTemplate, error
 // BuildVolumeServerTemplate builds the requested volume template to be used in a CreateServerRequest
 func (vb *VolumeBuilder) BuildVolumeServerTemplate(apiInstance *instance.API, apiBlock *block.API) (*instance.VolumeServerTemplate, error) {
 	if vb.SnapshotID != nil {
-		return vb.buildSnapshotVolume(apiInstance)
+		return vb.buildSnapshotVolume(apiInstance, apiBlock)
 	}
 
 	if vb.VolumeID != nil {
