@@ -8,6 +8,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core"
 	block "github.com/scaleway/scaleway-cli/v2/internal/namespaces/block/v1alpha1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
+	"github.com/scaleway/scaleway-cli/v2/internal/testhelpers"
 	blockSDK "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
@@ -123,7 +124,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					size := ctx.Result.(*instanceSDK.Server).Volumes["0"].Size
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "0")
+					size := volume.Size
 					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
 				},
 				core.TestCheckExitCode(0),
@@ -143,7 +146,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					size := ctx.Result.(*instanceSDK.Server).Volumes["0"].Size
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "0")
+					size := volume.Size
 					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
 				},
 			),
@@ -166,7 +171,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					size := ctx.Result.(*instanceSDK.Server).Volumes["0"].Size
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "0")
+					size := volume.Size
 					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
 				},
 			),
@@ -184,8 +191,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					size0 := ctx.Result.(*instanceSDK.Server).Volumes["0"].Size
-					size1 := ctx.Result.(*instanceSDK.Server).Volumes["1"].Size
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					size0 := testhelpers.MapTValue(t, server.Volumes, "0").Size
+					size1 := testhelpers.MapTValue(t, server.Volumes, "1").Size
 					assert.Equal(t, 10*scw.GB, instance.SizeValue(size0), "Size of volume should be 10 GB")
 					assert.Equal(t, 10*scw.GB, instance.SizeValue(size1), "Size of volume should be 10 GB")
 				},
@@ -195,27 +203,24 @@ func Test_CreateServer(t *testing.T) {
 		}))
 
 		t.Run("valid double snapshot", core.Test(&core.TestConfig{
-			Commands: instance.GetCommands(),
-			BeforeFunc: core.BeforeFuncCombine(
-				core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu_bionic root-volume=local:20GB stopped=true")),
-				core.ExecStoreBeforeCmd("Snapshot", `scw instance snapshot create unified=true volume-id={{ (index .Server.Volumes "0").ID }}`),
+			Commands: core.NewCommandsMerge(
+				instance.GetCommands(),
+				block.GetCommands(),
 			),
-			Cmd: testServerCommand("image=ubuntu_bionic root-volume=block:{{ .Snapshot.Snapshot.ID }} additional-volumes.0=local:{{ .Snapshot.Snapshot.ID }} stopped=true"),
+			BeforeFunc: core.BeforeFuncCombine(
+				core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu_jammy root-volume=block:20GB stopped=true")),
+				core.ExecStoreBeforeCmd("Snapshot", `scw block snapshot create volume-id={{ (index .Server.Volumes "0").ID }} -w`),
+			),
+			Cmd: testServerCommand("image=ubuntu_jammy root-volume=block:{{ .Snapshot.ID }} additional-volumes.0=block:{{ .Snapshot.ID }} stopped=true"),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
-				func(t *testing.T, ctx *core.CheckFuncCtx) {
-					t.Helper()
-					assert.NotNil(t, ctx.Result)
-					size0 := ctx.Result.(*instanceSDK.Server).Volumes["0"].Size
-					size1 := ctx.Result.(*instanceSDK.Server).Volumes["1"].Size
-					assert.Equal(t, 20*scw.GB, instance.SizeValue(size0), "Size of volume should be 20 GB")
-					assert.Equal(t, 20*scw.GB, instance.SizeValue(size1), "Size of volume should be 20 GB")
-				},
+				testServerSBSVolumeSize("0", 20),
+				testServerSBSVolumeSize("1", 20),
 			),
 			AfterFunc: core.AfterFuncCombine(
 				deleteServer("Server"),
 				deleteServerAfterFunc(),
-				deleteSnapshot("Snapshot"),
+				deleteBlockSnapshot("Snapshot"),
 			),
 		}))
 
@@ -224,21 +229,14 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      testServerCommand("image=ubuntu_bionic additional-volumes.0=b:1G additional-volumes.1=b:5G additional-volumes.2=b:10G stopped=true"),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
-				func(t *testing.T, ctx *core.CheckFuncCtx) {
-					t.Helper()
-					assert.NotNil(t, ctx.Result)
-					size1 := ctx.Result.(*instanceSDK.Server).Volumes["1"].Size
-					size2 := ctx.Result.(*instanceSDK.Server).Volumes["2"].Size
-					size3 := ctx.Result.(*instanceSDK.Server).Volumes["3"].Size
-					assert.Equal(t, 1*scw.GB, instance.SizeValue(size1), "Size of volume should be 1 GB")
-					assert.Equal(t, 5*scw.GB, instance.SizeValue(size2), "Size of volume should be 5 GB")
-					assert.Equal(t, 10*scw.GB, instance.SizeValue(size3), "Size of volume should be 10 GB")
-				},
+				testServerSBSVolumeSize("1", 1),
+				testServerSBSVolumeSize("2", 5),
+				testServerSBSVolumeSize("3", 10),
 			),
 			AfterFunc: deleteServerAfterFunc(),
 		}))
 
-		t.Run("sbs additional volumes", core.Test(&core.TestConfig{
+		t.Run("sbs additional volumes from id", core.Test(&core.TestConfig{
 			Commands: core.NewCommandsMerge(
 				instance.GetCommands(),
 				block.GetCommands(),
@@ -251,7 +249,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, ctx.Result.(*instanceSDK.Server).Volumes["1"].VolumeType)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "1")
+					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, volume.VolumeType)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -260,6 +260,27 @@ func Test_CreateServer(t *testing.T) {
 			),
 		}))
 
+		t.Run("sbs additional volumes", core.Test(&core.TestConfig{
+			Commands: core.NewCommandsMerge(
+				instance.GetCommands(),
+				block.GetCommands(),
+			),
+			Cmd: testServerCommand("image=ubuntu_jammy additional-volumes.0=sbs:20G stopped=true"),
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(0),
+				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					t.Helper()
+					assert.NotNil(t, ctx.Result)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "1")
+					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, volume.VolumeType)
+				},
+			),
+			AfterFunc: core.AfterFuncCombine(
+				deleteServerAfterFunc(),
+			),
+		}))
+
 		t.Run("use sbs root volume", core.Test(&core.TestConfig{
 			Commands: core.NewCommandsMerge(
 				instance.GetCommands(),
@@ -274,7 +295,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, ctx.Result.(*instanceSDK.Server).Volumes["0"].VolumeType)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "0")
+					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, volume.VolumeType)
 				},
 			),
 			AfterFunc: core.AfterFuncCombine(
@@ -293,7 +316,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, ctx.Result.(*instanceSDK.Server).Volumes["0"].VolumeType)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					volume := testhelpers.MapTValue(t, server.Volumes, "0")
+					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, volume.VolumeType)
 				},
 			),
 			AfterFunc: core.AfterFuncCombine(
@@ -312,7 +337,9 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					rootVolume, rootVolumeExists := ctx.Result.(*instanceSDK.Server).Volumes["0"]
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+
+					rootVolume, rootVolumeExists := server.Volumes["0"]
 					assert.True(t, rootVolumeExists)
 					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, rootVolume.VolumeType)
 
@@ -343,8 +370,10 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.NotEmpty(t, ctx.Result.(*instanceSDK.Server).PublicIP.Address)
-					assert.Equal(t, false, ctx.Result.(*instanceSDK.Server).PublicIP.Dynamic)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					assert.NotNil(t, server.PublicIP)
+					assert.NotEmpty(t, server.PublicIP.Address)
+					assert.Equal(t, false, server.PublicIP.Dynamic)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -359,8 +388,10 @@ func Test_CreateServer(t *testing.T) {
 					t.Helper()
 					assert.NoError(t, ctx.Err)
 					assert.NotNil(t, ctx.Result)
-					assert.NotEmpty(t, ctx.Result.(*instanceSDK.Server).PublicIP.Address)
-					assert.Equal(t, true, ctx.Result.(*instanceSDK.Server).DynamicIPRequired)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					assert.NotNil(t, server.PublicIP)
+					assert.NotEmpty(t, server.PublicIP.Address)
+					assert.Equal(t, true, server.DynamicIPRequired)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -375,8 +406,10 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.NotEmpty(t, ctx.Result.(*instanceSDK.Server).PublicIP.Address)
-					assert.Equal(t, false, ctx.Result.(*instanceSDK.Server).PublicIP.Dynamic)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					assert.NotNil(t, server.PublicIP)
+					assert.NotEmpty(t, server.PublicIP.Address)
+					assert.Equal(t, false, server.PublicIP.Dynamic)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -391,8 +424,10 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.NotEmpty(t, ctx.Result.(*instanceSDK.Server).PublicIP.Address)
-					assert.Equal(t, false, ctx.Result.(*instanceSDK.Server).PublicIP.Dynamic)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
+					assert.NotNil(t, server.PublicIP)
+					assert.NotEmpty(t, server.PublicIP.Address)
+					assert.Equal(t, false, server.PublicIP.Dynamic)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -406,7 +441,7 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					require.NotNil(t, ctx.Result, "Server is nil")
-					server := ctx.Result.(*instanceSDK.Server)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					assert.Len(t, server.PublicIPs, 1)
 					assert.Equal(t, instanceSDK.ServerIPIPFamilyInet6, server.PublicIPs[0].Family)
 				},
@@ -423,7 +458,7 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result, "server is nil")
-					server := ctx.Result.(*instanceSDK.Server)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					assert.Len(t, server.PublicIPs, 2)
 					assert.Equal(t, instanceSDK.ServerIPIPFamilyInet, server.PublicIPs[0].Family)
 					assert.True(t, server.PublicIPs[0].Dynamic)
@@ -441,7 +476,7 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result, "server is nil")
-					server := ctx.Result.(*instanceSDK.Server)
+					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					assert.Len(t, server.PublicIPs, 2)
 					assert.Equal(t, instanceSDK.ServerIPIPFamilyInet, server.PublicIPs[0].Family)
 					assert.Equal(t, instanceSDK.ServerIPIPFamilyInet6, server.PublicIPs[1].Family)
