@@ -11,7 +11,7 @@ import (
 func Test_AddACL(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl add 1.2.3.4 instance-id={{ .Instance.ID }} --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -25,7 +25,7 @@ func Test_AddACL(t *testing.T) {
 
 	t.Run("Simple with description", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl add 1.2.3.4 instance-id={{ .Instance.ID }} description=some-unique-description --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -39,7 +39,7 @@ func Test_AddACL(t *testing.T) {
 
 	t.Run("Multiple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl add 1.2.3.4 192.168.1.0/30 10.10.10.10 instance-id={{ .Instance.ID }} --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -53,7 +53,7 @@ func Test_AddACL(t *testing.T) {
 
 	t.Run("Multiple with description", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl add 1.2.3.4 192.168.1.0/30 10.10.10.10 instance-id={{ .Instance.ID }} description=some-unique-description --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -69,7 +69,7 @@ func Test_AddACL(t *testing.T) {
 func Test_DeleteACL(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl delete 0.0.0.0/0 instance-id={{ .Instance.ID }} --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -84,7 +84,7 @@ func Test_DeleteACL(t *testing.T) {
 	t.Run("Multiple when set", core.Test(&core.TestConfig{
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createInstance("PostgreSQL-12"),
+			fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}"),
 			core.ExecBeforeCmd("scw rdb acl add 1.2.3.4 192.168.1.0/32 10.10.10.10 instance-id={{ .Instance.ID }} --wait"),
 		),
 		Cmd: "scw rdb acl delete 1.2.3.4/32 192.168.1.0/32 10.10.10.10/32 instance-id={{ .Instance.ID }} --wait",
@@ -101,7 +101,7 @@ func Test_DeleteACL(t *testing.T) {
 	t.Run("Multiple when not set", core.Test(&core.TestConfig{
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createInstance("PostgreSQL-12"),
+			fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}"),
 			core.ExecBeforeCmd("scw rdb acl add 192.168.1.0/32 instance-id={{ .Instance.ID }} --wait"),
 		),
 		Cmd: "scw rdb acl delete 1.2.3.4/32 192.168.1.0/32 10.10.10.10/32 instance-id={{ .Instance.ID }} --wait",
@@ -119,7 +119,7 @@ func Test_DeleteACL(t *testing.T) {
 func Test_SetACL(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb acl set 1.2.3.4 instance-id={{ .Instance.ID }} descriptions.0=something --wait",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -136,7 +136,7 @@ func Test_SetACL(t *testing.T) {
 	t.Run("Multiple", core.Test(&core.TestConfig{
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createInstance("PostgreSQL-12"),
+			fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}"),
 			core.ExecBeforeCmd("scw rdb acl add 1.2.3.4 192.168.1.0/32 10.10.10.10 instance-id={{ .Instance.ID }} --wait"),
 		),
 		Cmd: "scw rdb acl set 1.2.3.4 192.168.1.0/31 11.11.11.11 instance-id={{ .Instance.ID }} descriptions.0=first descriptions.1=second descriptions.2=third --wait",
