@@ -4,7 +4,7 @@ import (
 	"context"
 	"time"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-sdk-go/api/rdb/v1"
 )
 
