@@ -17,21 +17,7 @@ func CreateGateway(metakey string) core.BeforeFunc {
 func CreateGatewayNetwork(metakey string) core.BeforeFunc {
 	return core.ExecStoreBeforeCmd(
 		"GWNT",
-		"scw vpc-gw gateway-network create gateway-id={{ ."+metakey+".ID }} private-network-id={{ .PN.ID }} --wait",
-	)
-}
-
-func CreateGatewayNetworkDHCP(metakey string) core.BeforeFunc {
-	return core.ExecStoreBeforeCmd(
-		"GWNT",
-		"scw vpc-gw gateway-network create gateway-id={{ ."+metakey+".ID }} private-network-id={{ .PN.ID }} enable-dhcp=true dhcp-id={{ .DHCP.ID }} --wait",
-	)
-}
-
-func CreateDHCP() core.BeforeFunc {
-	return core.ExecStoreBeforeCmd(
-		"DHCP",
-		"scw vpc-gw dhcp create subnet=192.168.1.0/24 enable-dynamic=true",
+		"scw vpc-gw gateway-network create gateway-id={{ ."+metakey+".ID }} private-network-id={{ .PN.ID }} ipam-config.push-default-route=true --wait",
 	)
 }
 
@@ -46,7 +32,3 @@ func DeleteGateway(metakey string) core.AfterFunc {
 func DeleteIPVpcGw(metakey string) core.AfterFunc {
 	return core.ExecAfterCmd("scw vpc-gw ip delete {{ ." + metakey + ".IP.ID }}")
 }
-
-func DeleteDHCP() core.AfterFunc {
-	return core.ExecAfterCmd("scw vpc-gw dhcp delete {{ .DHCP.ID }}")
-}
